##  Activating and Deactivating the Mapping
You can activate or deactivate a mapping in the configuration by checking or unchecking the Active checkbox. This allows you to test different settings on other parts of the configuration without syncing the data.
